@@ -18,11 +18,11 @@ OutputsModel::OutputsModel(Options o, QObject *parent)
 {
 
     if (o & VirtualIncluded) {
-        m_outputs << Output{Output::Virtual, nullptr, i18n("New Virtual Output"), QStringLiteral("Virtual"), {}};
+        m_outputs << Output{Output::Virtual, nullptr, i18n("Share virtual screen"), QStringLiteral("Virtual"), {}};
     }
 
     if (o & RegionIncluded) {
-        m_outputs << Output{Output::Region, nullptr, i18n("Rectangular Region"), u"Region"_s, {}};
+        m_outputs << Output{Output::Region, nullptr, i18n("Share region"), u"Region"_s, {}};
     }
 
     if (o & OutputsExcluded) {
@@ -33,7 +33,7 @@ OutputsModel::OutputsModel(Options o, QObject *parent)
 
     // Only show the full workspace if there's several outputs
     if (screens.count() > 1 && (o & WorkspaceIncluded)) {
-        m_outputs.prepend(Output{Output::Workspace, nullptr, i18n("Full Workspace"), u"Workspace"_s, {}});
+        m_outputs.prepend(Output{Output::Workspace, nullptr, i18n("Share full Workspace"), u"Workspace"_s, {}});
     }
 
     connect(qGuiApp, &QGuiApplication::screenRemoved, this, [this](QScreen *screen) {
@@ -100,6 +100,11 @@ OutputsModel::OutputsModel(Options o, QObject *parent)
         const QPoint pos = screen->geometry().topLeft();
         m_outputs << Output(type, screen, displayText, QStringLiteral("%1x%2").arg(pos.x()).arg(pos.y()), screen->name());
     }
+
+    // Partition so that real outputs come first. This is the order in which we want to visualize them in the UI.
+    std::ranges::stable_partition(m_outputs, [](const Output &o) {
+        return !o.isSynthetic();
+    });
 }
 
 OutputsModel::~OutputsModel() = default;
@@ -117,6 +122,9 @@ QHash<int, QByteArray> OutputsModel::roleNames() const
         {Qt::CheckStateRole, "checked"},
         {ScreenRole, "screen"},
         {NameRole, "name"},
+        {IsSyntheticRole, "isSynthetic"},
+        {DescriptionRole, "description"},
+        {GeometryRole, "geometry"},
     };
 }
 
@@ -130,9 +138,14 @@ QVariant OutputsModel::data(const QModelIndex &index, int role) const
     switch (role) {
     case ScreenRole:
         return QVariant::fromValue(output.screen());
-        return 0;
     case NameRole:
         return output.name();
+    case IsSyntheticRole:
+        return output.isSynthetic();
+    case DescriptionRole:
+        return output.description();
+    case GeometryRole:
+        return output.screen() ? output.screen()->geometry() : QRect();
     case Qt::DecorationRole:
         return QIcon::fromTheme(output.iconName());
     case Qt::DisplayRole:
@@ -208,3 +221,61 @@ QString OutputsModel::virtualScreenIdForApp(const QString &appId)
     }
     return id;
 }
+
+QString Output::iconName() const
+{
+    switch (m_outputType) {
+    case Laptop:
+        return QStringLiteral("computer-laptop-symbolic");
+    case Television:
+        return QStringLiteral("video-television-symbolic");
+    case Region:
+        return QStringLiteral("transform-crop-symbolic");
+    case Virtual:
+        return QStringLiteral("window-duplicate-symbolic");
+    case Workspace:
+        return QStringLiteral("preferences-desktop-display-randr-symbolic");
+    case Monitor:
+        return QStringLiteral("monitor-symbolic");
+    case Unknown:
+        break;
+    }
+    return QStringLiteral("video-display-symbolic");
+}
+
+QString Output::description() const
+{
+    switch (m_outputType) {
+    case Workspace:
+        return i18nc("@info", "Share the entire workspace across all screens");
+    case Virtual:
+        return i18nc("@info", "Creates a screen inside a window, then share");
+    case Region:
+        return i18nc("@info", "Crops a specific area of your screens");
+    case Laptop:
+    case Monitor:
+    case Television:
+    case Unknown:
+        // Unused
+        break;
+    }
+    return {};
+}
+
+bool Output::isSynthetic() const
+{
+    switch (outputType()) {
+    case Output::Workspace:
+    case Output::Region:
+    case Output::Virtual:
+        return true;
+    case Output::Laptop:
+    case Output::Monitor:
+    case Output::Television:
+    case Output::Unknown:
+        break;
+    }
+    return false;
+}
+
+#include "moc_outputsmodel.cpp"
