@@ -129,6 +129,19 @@ public:
         Q_EMIT hasSelectionChanged();
     }
 
+    /*
+        \brief used for finding indexes based on whether they intersect with a given screen geometry. IOW: if the window is visible on that screen
+        Mind that the call signature must be kept in sync with OutputsModel! We invoke it on both the output and window model.
+    */
+    Q_INVOKABLE [[nodiscard]] bool geometryIntersects(const QModelIndex &index, const QRect &geometry) const
+    {
+        if (!checkIndex(index, CheckIndexOption::IndexIsValid)) {
+            qWarning() << "Invalid index for geometry intersection check:" << index;
+            return false;
+        }
+        return data(index, KWayland::Client::PlasmaWindowModel::Geometry).toRect().intersects(geometry);
+    }
+
 Q_SIGNALS:
     void hasSelectionChanged();
 
@@ -142,7 +155,7 @@ ScreenChooserDialog::ScreenChooserDialog(const QString &appName, bool multiple,
     Q_ASSERT(types != 0);
 
     QVariantMap props = {
-        {u"title"_s, i18n("Screen Sharing")},
+        {u"title"_s, i18nc("@title:window %1 is an application name (e.g. Falkon)", "Share screen with %1", Utils::applicationName(appName))},
         {u"multiple"_s, multiple},
     };
 
@@ -164,6 +177,8 @@ ScreenChooserDialog::ScreenChooserDialog(const QString &appName, bool multiple,
         props.insert(u"outputsModel"_s, QVariant::fromValue<QObject *>(model));
         numberOfMonitors += model->rowCount(QModelIndex());
         connect(this, &ScreenChooserDialog::clearSelection, model, &OutputsModel::clearSelection);
+    } else {
+        props.insert(u"outputsModel"_s, QVariant::fromValue(nullptr));
     }
 
     int numberOfWindows = 0;
@@ -174,6 +189,8 @@ ScreenChooserDialog::ScreenChooserDialog(const QString &appName, bool multiple,
         props.insert(u"windowsModel"_s, QVariant::fromValue<QObject *>(windowsProxy));
         connect(this, &ScreenChooserDialog::clearSelection, windowsProxy, &FilteredWindowModel::clearSelection);
         numberOfWindows += model->rowCount(QModelIndex());
+    } else {
+        props.insert(u"windowsModel"_s, QVariant::fromValue(nullptr));
     }
 
     const QString applicationName = Utils::applicationName(appName);
@@ -316,4 +333,5 @@ void ScreenChooserDialog::accept()
     QuickDialog::accept();
 }
 
+#include "moc_screenchooserdialog.cpp"
 #include "screenchooserdialog.moc"
